@@ -13,8 +13,7 @@ split_file = function(lines, set.preamble = TRUE, patterns = knit_patterns$get()
   }
 
   markdown_mode = identical(patterns, all_patterns$md)
-  i = group_indices(grepl(chunk.begin, lines), grepl(chunk.end, lines), lines, markdown_mode)
-  groups = unname(split(lines, i))
+  groups = divide_chunks(lines, chunk.begin, chunk.end, markdown_mode)
 
   if (set.preamble)
     knit_concord$set(inlines = sapply(groups, length)) # input line numbers for concordance
@@ -41,6 +40,12 @@ split_file = function(lines, set.preamble = TRUE, patterns = knit_patterns$get()
   })
 }
 
+# divide lines of input into code/text chunks
+divide_chunks = function(x, begin, end, md = TRUE) {
+  i = group_indices(grepl(begin, x), grepl(end, x), x, md)
+  unname(split(x, i))
+}
+
 extract_params_src = function(chunk.begin, line) {
   trimws(gsub(chunk.begin, '\\1', line))
 }
@@ -132,8 +137,9 @@ parse_block = function(code, header, params.src, markdown_mode = out_format('mar
       deps[deps < 0] = length(.knitEnv$labels) + deps[deps < 0]
       deps = .knitEnv$labels[deps[deps > 0]]
     }
-    for (i in deps)
-      dep_list$set(setNames(list(c(dep_list$get(i), label)), i))
+    if (is.character(deps)) {
+      for (i in deps) dep_list$set(setNames(list(c(dep_list$get(i), label)), i))
+    } else warning2("Invalid chunk option 'dependson' (must be character or numeric)")
   }
 
   # for quarto only
@@ -394,12 +400,13 @@ strip_white = function(x, test_strip = is_blank) {
 parse_chunk = function(x, rc = knit_patterns$get('ref.chunk')) {
   if (length(x) == 0L) return(x)
   x = c(x)  # drop attributes of code (e.g. chunk_opts)
-  if (!group_pattern(rc) || !any(idx <- grepl(rc, x))) return(x)
+  if (!group_pattern(rc) || length(idx <- grep(rc, x)) == 0) return(x)
 
   labels = sub(rc, '\\1', x[idx])
-  code = knit_code$get(labels)
+  code = knit_code$get()
+  i = labels %in% names(code)
+  idx = idx[i]; code = code[labels[i]]
   indent = gsub('^(\\s*).*', '\\1', x[idx])
-  if (length(labels) <= 1L) code = list(code)
   code = mapply(indent_block, code, indent, SIMPLIFY = FALSE, USE.NAMES = FALSE)
 
   x = as.list(x)
@@ -464,12 +471,7 @@ match_chunk_end = function(pattern, line, i, b, lines) {
     if (!any(match_chunk_begin(pattern, lines[i + 1:(k - 1)], '^\\1`*\\\\{')))
       return(FALSE)
   }
-  # TODO: clean up the exceptions here (although perhaps some may never update again)
-  signal = if (getOption('knitr.unbalanced.chunk', xfun::check_old_package(
-    c('ensembleR', 'FSinR', 'liger', 'microsamplingDesign', 'mmpf', 'rSEA', 'StructFDR', 'TRMF'),
-    c('0.1.0', '2.0.5', '2.0.1', '1.0.8', '0.0.5', '2.1.1', '1.4', '0.1.5')
-  ))) warning2 else stop2
-  signal(
+  stop2(
     'The closing fence on line ', i, ' ("', line, '") in ', current_input(),
     ' does not match the opening fence "',
     gsub('\\^(\\s*`+).*', '\\1', pattern), '" on line ', b, '. You are recommended to ',
@@ -477,7 +479,6 @@ match_chunk_end = function(pattern, line, i, b, lines) {
     'the same numbers of backticks and same level of indentation (or blockquote). ',
     'See https://yihui.org/en/2021/10/unbalanced-delimiters/ for more info.'
   )
-  TRUE
 }
 
 #' Get all chunk labels in a document
